@@ -3,4 +3,4 @@
 # SPDX-License-Identifier: CC0-1.0
 
 $EXTRACTRC `find . -name \*.kcfg` >> rc.cpp
-$XGETTEXT `find . -name "*.cpp" -o $podir/krdpserver.pot
+$XGETTEXT `find . -name "*.cpp"` -o $podir/krdpserver.pot
